@@ -7,9 +7,6 @@ from wemake_python_styleguide.constants import SPECIAL_ARGUMENT_NAMES_WHITELIST
 from wemake_python_styleguide.logic import nodes, walk
 from wemake_python_styleguide.logic.arguments import call_args
 
-#: Nodes that can be annotated.
-_AnnNodes = (ast.AnnAssign, ast.arg)
-
 
 def is_class_context(node: ast.AST) -> bool:
     """
@@ -73,32 +70,6 @@ def is_self(node: ast.AST) -> bool:
     )
 
 
-def is_annotation(node: ast.AST) -> bool:
-    """
-    Detects if node is an annotation. Or a part of it.
-
-    We use this predicate to allow all types of repetetive
-    function and instance annotations.
-    """
-    if not isinstance(node, (ast.Str, ast.List, ast.Tuple, ast.Subscript)):
-        return False
-
-    annotated = walk.get_closest_parent(node, (*_AnnNodes, *FunctionNodes))
-    if isinstance(annotated, FunctionNodes):
-        contains_node = bool(
-            annotated.returns and
-            walk.is_contained_by(node, annotated.returns),
-        )
-        return node == annotated.returns or contains_node
-    elif isinstance(annotated, _AnnNodes):
-        contains_node = bool(
-            annotated.annotation and
-            walk.is_contained_by(node, annotated.annotation),
-        )
-        return node == annotated.annotation or contains_node
-    return False
-
-
 def is_primitive(node: ast.AST) -> bool:
     """
     Detects if node is a form of a primitive value.
